s3fs
====

|Build Status| |Doc Status|

S3FS builds on aiobotocore_ to provide a convenient Python filesystem interface for S3.

View the documentation_ for s3fs.

.. _documentation: http://s3fs.readthedocs.io/en/latest/
.. _aiobotocore: https://aiobotocore.readthedocs.io/en/latest/

.. |Build Status| image:: https://github.com/dask/s3fs/workflows/CI/badge.svg
    :target: https://github.com/dask/s3fs/actions
    :alt: Build Status
.. |Doc Status| image:: https://readthedocs.org/projects/s3fs/badge/?version=latest
    :target: https://s3fs.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status
